from . import run

def main():
    run()

if __name__ == '__main__':
    main()
